Struct gitlab_runner::Runner[][src]

pub struct Runner { /* fields omitted */ }

Implementations

Request a new job from gitlab

Wait for at least one of the current jobs to finish

Sleep for the given duration while keeping track of outstanding jobs